@@ -1,4 +1,5 @@
 import builtins
+from distutils.util import strtobool
 
 from drf_auth_service.common.backends import BaseBackend
 from drf_auth_service.common.enums import LogsType
@@ -66,7 +67,10 @@ class RegisterManager:
     def init_configs(self):
         for conf in Config.objects.filter(service=self.request.service):
             try:
-                self.configs[conf.key] = getattr(builtins, conf.type)(conf.value)
+                if conf.type == 'bool':
+                    self.configs[conf.key] = strtobool(conf.value)
+                else:
+                    self.configs[conf.key] = getattr(builtins, conf.type)(conf.value)
             except AttributeError:
                 self.configs[conf.key] = conf.value
 
