@@ -141,13 +141,13 @@ class ActivationCode(models.Model):
     def create_token(user, key_type, for_phone=False):
         from drf_auth_service.settings import settings
         if settings.DEBUG_MODE:
-            key = settings.DEBUG_KEY
+            token = ActivationCode(key=settings.DEBUG_KEY)
         else:
             password_reset_token_validation_time = 24
             now_minus_expiry_time = timezone.now() - timedelta(hours=password_reset_token_validation_time)
             ActivationCode.clear_expired(now_minus_expiry_time, key_type=key_type)
             key = generate_code() if for_phone else generate_token()
-        token, _ = ActivationCode.objects.update_or_create(user=user, key_type=key_type, defaults={'key': key})
+            token, _ = ActivationCode.objects.update_or_create(user=user, key_type=key_type, defaults={'key': key})
         return token
 
 
