@@ -35,8 +35,9 @@ class UserViewSet(
         api_settings.SIGNING_KEY = request.service.secret_token
         serializer = self.get_serializer_create(data=request.data)
         serializer.is_valid(raise_exception=True)
-        ActivationCode.make_user_active(self.get_object())
-        return Response(BaseBackend.get_jwt_response(self.get_object()))
+        user = self.get_user_by_username(request.service, serializer.validated_data['username'])
+        ActivationCode.make_user_active(user)
+        return Response(BaseBackend.get_jwt_response(user))
 
     @action(detail=False, methods=['POST'], url_path='resend-confirmation',
             serializer_class=settings.SERIALIZERS.RETURN_SUCCESS_SERIALIZER,
